@@ -504,7 +504,7 @@ def get_row(target_value,column_name=None,index_value=None,df=None):
     column_names = make_list(column_name or df.columns.tolist())
     for i,column in enumerate(column_names):
         search_column(target_value,column_name=None,column_index=0,df=None,exact_match=True)
-        value = gdf[column][index_value]
+        value = df[column][index_value]
         if value.lower() == target_value.lower():
             return df,i
     return None,None
